ReleasePlatform enum

ReleasePlatform 打包平台

Inheritance
Available extensions

Values

android → const ReleasePlatform

Android 打包平台

const ReleasePlatform('Android', 'apk', '.apk')
windows → const ReleasePlatform

Windows 打包平台

const ReleasePlatform('Windows', 'windows', '.zip')

Properties

command String
平台命令
final
fileSuffix String
文件后缀
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
平台名称
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReleasePlatform>
A constant List of the values in this enum, in order of their declaration.