VersionManage class
VersionManage 版本管理
Constructors
- VersionManage()
-
VersionManage 版本管理
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectName → String
-
项目名称
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
版本号
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectVersionType(
) → void - 选择版本类型
-
setVersion(
String newVersion) → void - 设置版本号
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadPubspecFile(
) → List< String> - 读取 pubspec.yaml